# coding: utf-8
class Const:
    ActionDenyAccess = "deny_access"
    ActionAllowAccess = "allow_access"
    ActionRedirectProtocol = "redirect_protocol"
    ActionRedirectRequest = "redirect_request"
    ActionRequestHeader = "request_header"
    ActionDownloadSpeedLimit = "download_speed_limit"
    ActionResponseHeader = "response_header"
    ActionCacheTime = "cache_time"
    ActionCacheKey = "cache_key"
    ActionCompression = "compression"
    ActionVideoDrag = "video_drag"
    ActionOriginResponseHeader = "origin_response_header"
    ActionOriginRequestHeader = "origin_request_header"
    ActionOriginRange = "origin_range"
    ActionOriginFollow = "origin_follow"
    ActionOriginTCPTimeout = "origin_tcp_timeout"
    ActionOriginHTTPTimeout = "origin_http_timeout"
    ActionOriginHost = "origin_host"
    # ActionVariable = "variable"
    # ActionAccessPlugin = "access_plugin"
    # ActionRewritePlugin = "rewrite_plugin"
    # ActionHeaderFilterPlugin = "header_filter_plugin"
    # ActionBodyFilterPlugin = "body_filter_plugin"
    # ActionLogPlugin = "log_plugin"

    ConditionAlways = "always"
    ConditionRequestTime = "request_time"
    ConditionClientIP = "client_ip"
    ConditionRequestHeader = "request_header"
    ConditionHTTPOrigin = "http_origin"
    ConditionHTTPReferer = "http_referer"
    ConditionHTTPUserAgent = "http_ua"
    ConditionHTTPMethod = "http_method"
    ConditionHTTPProtocol = "protocol"
    ConditionHTTPUrl = "url"
    ConditionHTTPPathAndParam = "path_and_param"
    ConditionHTTPPath = "path"
    ConditionQueryString = "query_string"
    ConditionResponseHeader = "response_header"
    ConditionHTTPCode = "http_code"
    ConditionClientArea = "client_area"

    ConnectiveAnd = "and"
    ConnectiveOr = "or"

    OperatorEqual = "equal"
    OperatorNotEqual = "not_equal"
    OperatorMatch = "match"
    OperatorNotMatch = "not_match"
    OperatorPrefixMatch = "prefix_match"
    OperatorPrefixNotMatch = "prefix_not_match"
    OperatorSuffixMatch = "suffix_match"
    OperatorSuffixNotMatch = "suffix_not_match"
    OperatorExist = "exist"
    OperatorNotExist = "not_exist"
    OperatorRegexMatch = "regex_match"
    OperatorRegexNotMatch = "regex_not_match"
    OperatorBelongTo = "belong_to"
    OperatorNotBelongTo = "not_belong_to"

    EveryDay = "everyday"
    Weekday = "weekday"
    Period = "period"

    Monday = "mon"
    Tuesday = "tue"
    Wednesday = "wed"
    Thursday = "thur"
    Friday = "fri"
    Saturday = "sat"
    Sunday = "sun"

    GET = "get"
    POST = "post"
    HEAD = "head"
    DELETE = "delete"
    OPTIONS = "options"
    PURGE = "purge"
    PUT = "put"
    CONNECT = "connect"
    PATCH = "patch"

    HTTP = "http"
    HTTPS = "https"


    Second = "sec"
    Minute = "min"
    Hour = "hour"
    Day = "day"

    HTTPTimeout = "http_read_timeout"
    TCPTimeout = "tcp_connect_timeout"

    Set = "set"
    Delete = "delete"
    Append = "append"

    SpecificContentType = "customize"
    DefaultContentType = "default"

    QueryString = "query_string"
    RequestPath = "request_path"
    RequestHeader = "request_header"
    Cookie = "cookie"
    PathIgnoreCase = "path_ignore_case"

    FollowClient = "follow_client"

    IncludeAll = "include_all"
    IncludePart = "include_part"
    ExcludeAll = "exclude_all"
    ExcludePart = "exclude_part"

    CacheOriginFirst = "origin_first"
    CacheDefault = "default"

    FluxByte = "B"
    FluxKB = "KB"
    FluxMB = "MB"

    BandwidthBps = "B/s"
    BandwidthKBps = "KB/s"
    BandwidthMBps = "MB/s"

    TimeZoneEast8 = "+0800"

    SwitchTrue = "true"
    SwitchFalse = "false"


# coding: utf-8
import json
from typing import Optional

class Parameter(object):
    def __init__(self, raw: dict):
        self.name = raw.get('Name', '')
        self.values = raw.get('Values', [])

    def encode(self) -> dict:
        return {
            'Name': self.name,
            'Values': self.values
        }

class BaseAction(object):
    def __init__(self, raw: dict):
        self.parameters = []
        for p in raw.get('Parameters', []):
            self.parameters.append(Parameter(p))

    def encode(self) -> dict:
        return {
            'Parameters': [p.encode() for p in self.parameters]
        }

    def set(self, name: str, values: list) -> None:
        for p in self.parameters:
            if p.name == name:
                p.values = values
                return
        self.parameters.append(Parameter({
            'Name': name,
            'Values': values
        }))

    def get(self, name: str) -> (Optional[Parameter], bool):
        for p in self.parameters:
            if p.name == name:
                return p, True
        return None, False


    def remove(self, name: str) -> None:
        for i, p in enumerate(self.parameters):
            if p.name == name:
                self.parameters.pop(i)
                return
        return

class ActionGroup(object):
    def __init__(self, raw: dict):
        self.dimension = raw.get('Dimension', '')
        self.group_parameters = []
        for a in raw.get('GroupParameters', []):
            self.group_parameters.append(BaseAction(a))

    def encode(self) -> dict:
        return {
            'Dimension': self.dimension,
            'GroupParameters': [g.encode() for g in self.group_parameters]
        }

class Action(object):
    def __init__(self, raw: dict):
        self.action = raw.get('Action', '')
        self.groups = []
        for g in raw.get('Groups', []):
            self.groups.append(ActionGroup(g))

    def encode(self) -> dict:
        return {
            'Action': self.action,
            'Groups': [g.encode() for g in self.groups]
        }

    def get_action_group(self, dimension: str) -> (Optional[ActionGroup], bool):
        for g in self.groups:
            if g.dimension == dimension:
                return g, True
        return None, False

    def set_action_group(self, dimension: str, group: ActionGroup):
        for i, g in enumerate(self.groups):
            if g.dimension == dimension:
                self.groups[i] = group
                return
        self.groups.append(group)

    def remove_action_group(self, dimension: str) -> None:
        for i, g in enumerate(self.groups):
            if g.dimension == dimension:
                self.groups.pop(i)
                return
        return

class BaseCondition(object):
    def __init__(self, raw: dict):
        self.object = raw.get('Object', '')
        self.name = raw.get('Name')
        self.operator = raw.get('Operator')
        self.ignore_case = raw.get('IgnoreCase')
        self.time_zone = raw.get('TimeZone')
        self.value = raw.get('Value')

    def encode(self) -> dict:
        data = {
            'Object': self.object
        }
        if self.name:
            data['Name'] = self.name
        if self.operator:
            data['Operator'] = self.operator
        if self.ignore_case is not None:
            data['IgnoreCase'] = self.ignore_case
        if self.time_zone :
            data['TimeZone'] = self.time_zone
        if self.value:
            data['Value'] = self.value
        return data


class Condition(object):
    def __init__(self, raw: dict):
        self.is_group = raw.get('IsGroup', False)
        self.connective = raw.get('Connective', 'and')
        self.condition_groups = []
        self.condition = BaseCondition(raw.get('Condition', {}))
        if self.is_group:
            for c in raw.get('ConditionGroups', []):
                self.condition_groups.append(Condition(c))

    def encode(self) -> dict:
        if self.is_group:
            return {
                'IsGroup': self.is_group,
                'Connective': self.connective,
                'ConditionGroups': [c.encode() for c in self.condition_groups]
            }
        else:
            return {
                'IsGroup': self.is_group,
                'Condition': self.condition.encode()
            }

class IfBlock(object):
    def __init__(self, raw: dict):
        self.condition = Condition(raw.get('Condition', {}))
        self.actions = [Action(a) for a in raw.get('Actions', [])]
        self.sub_rules = [Rule(r) for r in raw.get('SubRules', [])]

    def encode(self) -> dict:
        return {
            'Condition': self.condition.encode(),
            'Actions': [a.encode() for a in self.actions],
            'SubRules': [r.encode() for r in self.sub_rules]
        }


class ElseBlock(object):
    def __init__(self, raw: dict):
        self.actions = [Action(a) for a in raw.get('Actions', [])]
        self.sub_rules = [Rule(r) for r in raw.get('SubRules', [])]

    def encode(self) -> dict:
        return {
            'Actions': self.actions,
            'SubRules': [r.encode() for r in self.sub_rules]
        }


class Rule(object):
    def __init__(self, raw: Optional[dict] = None):
        if raw and isinstance(raw, dict):
            self.desc = raw.get('Desc', '')
            self.if_block = IfBlock(raw.get('IfBlock', {}))
            self.else_block = ElseBlock(raw.get('ElseBlock', {}))
        else:
            self.desc = ''
            self.if_block = IfBlock({})
            self.else_block = ElseBlock({})

    def encode(self) -> dict:
        return {
            'Desc': self.desc,
            'IfBlock': self.if_block.encode(),
            'ElseBlock': self.else_block.encode()
        }

    def encode_to_string(self) -> str:
        return json.dumps(self.encode())

    def decode_from_string(self, rule: str) -> None:
        rule = json.loads(rule)
        self.desc = rule.get('Desc', '')
        self.if_block = IfBlock(rule.get('IfBlock', {}))
        self.else_block = ElseBlock(rule.get('ElseBlock', {}))



# coding: utf-8
from rule_engine.Rule import Action, BaseCondition

def action_allow_access() -> Action:
    """
    动作: 允许访问
    :return: Action
    """
    action = Action({
        "Action": "allow_access",
        "Groups": [{
            "Dimension": "allow_access",
            "GroupParameters": []
        }]
    })
    return action

def action_deny_access() -> Action:
    """
    动作: 禁止访问，返回403
    :return: Action
    """
    action = Action({
        "Action": "deny_access",
        "Groups": [{
            "Dimension": "deny_access",
            "GroupParameters": [{
                "Parameters": [{
                    "Name": "status_code",
                    "Values": ["403"]
                }]
            }]
        }]
    })
    return action

def action_redirect_request() -> Action:
    """
    动作: 重定向改写，将原始请求地址 /path_source?a=1&b=2&c=3 重定向到 https://www.test.com/path_target?a=1&b=2，仅保留 a 和 b 两个参数
    :return: Action
    """
    action = Action({
        "Action": "redirect_request",
        "Groups": [{
            "Dimension": "redirect_request",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"source_path",
                        "Values": ["/path_source"]
                    },
                    {
                        "Name":"target_path",
                        "Values": ["/path_target"]
                    },
                    {
                        "Name":"status_code",
                        "Values": ["302"]
                    },
                    {
                        "Name":"protocol",
                        "Values": ["https"]
                    },
                    {
                        "Name":"target_host",
                        "Values": ["www.test.com"]
                    },
                    {
                        "Name":"target_query_action",
                        "Values": ["include_part"]
                    },
                    {
                        "Name":"target_query_values",
                        "Values": ["a", "b"]
                    }
                ]
            }]
        }]
    })
    return action

def action_redirect_protocol() -> Action:
    """
    动作： 协议强制跳转，将 http 协议强制跳转为 https 协议，301 跳转
    :return: Action
    """
    action = Action({
        "Action":"redirect_protocol",
        "Groups": [{
            "Dimension":"redirect_protocol",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"status_code",
                        "Values": ["301"]
                    },
                    {
                        "Name":"protocol",
                        "Values": ["https"]
                    }
                ]
            }]
        }]
    })
    return action

def action_download_speed_limit() -> Action:
    """
    动作： 限速，限速 100KB/s，仅在文件大小超过 1000MB 后限速
    :return: Action
    """
    action = Action({
        "Action":"download_speed_limit",
        "Groups": [{
            "Dimension":"download_speed_limit",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"rate",
                        "Values": ["100"]
                    },
                    {
                        "Name":"rate_unit",
                        "Values": ["KB/s"]
                    },
                    {
                        "Name": "after_size",
                        "Values": ["1000"]
                    },
                    {
                        "Name": "after_size_unit",
                        "Values": ["MB"]
                    }
                ]
            }]
        }]
    })
    return action

def action_response_header() -> Action:
    """
    动作： 响应头改写，将客户端响应头 X-H1 改为 X-H2
    :return: Action
    """
    action = Action({
        "Action":"response_header",
        "Groups": [{
            "Dimension":"response_header",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name": "action",
                        "Values": ["set"]
                    },
                    {
                        "Name":"header_name",
                        "Values": ["X-H1"]
                    },
                    {
                        "Name":"header_value",
                        "Values": ["X-H2"]
                    }
                ]
            }]
        }]
    })
    return action

def action_request_header() -> Action:
    """
    动作： 请求头改写，将客户端请求头 X-H1 改为 X-H2
    :return: Action
    """
    action = Action({
        "Action":"request_header",
        "Groups": [{
            "Dimension":"request_header",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name": "action",
                        "Values": ["set"]
                    },
                    {
                        "Name":"header_name",
                        "Values": ["X-H1"]
                    },
                    {
                        "Name":"header_value",
                        "Values": ["X-H2"]
                    }
                ]
            }]
        }]
    })
    return action

def action_cache_key() -> Action:
    """
    动作： 缓存键改写，"将缓存键改写为包含以下字段：
    - 查询字符串：缓存键参数部分仅保留 a 和 b 两个参数
    - 请求路径：缓存键路径部分，将原始请求路径 /path_source 改写为 /path_target
    - 请求头: 取 X-H1 头部值计算缓存键，并忽略大小写
    - Cookie：取 Cookie 中的 c1 和 c2 计算缓存键，并忽略大小写"
    :return: Action
    """
    action = Action({
        "Action":"cache_key",
        "Groups": [
            {
                "Dimension":"query_string",
                "GroupParameters": [{
                    "Parameters": [
                        {
                            "Name": "query_action",
                            "Values": ["include_part"]
                        },
                        {
                            "Name":"query_names",
                            "Values": ["a", "b"]
                        },
                        {
                            "Name":"ignore_case",
                            "Values": ["false"]
                        }
                    ]
                }]
            },
            {
                "Dimension":"request_path",
                "GroupParameters": [{
                    "Parameters": [
                        {
                            "Name": "source_path",
                            "Values": ["/path_source"]
                        },
                        {
                            "Name":"target_path",
                            "Values": ["/path_target"]
                        }
                    ]
                }]
            },
            {
                "Dimension":"request_header",
                "GroupParameters": [{
                    "Parameters": [
                        {
                            "Name": "header_names",
                            "Values": ["X-H1"]
                        },
                        {
                            "Name":"ignore_case",
                            "Values": ["true"]
                        }
                    ]
                }]
            },
            {
                "Dimension":"cookie",
                "GroupParameters": [{
                    "Parameters": [
                        {
                            "Name":"cookie_action",
                            "Values": ["include_part"]
                        },
                        {
                            "Name":"cookie_names",
                            "Values": ["c1", "c2"]
                        },
                        {
                            "Name":"ignore_case",
                            "Values": ["true"]
                        }
                    ]
                }]
            }
        ]
    })
    return action

def action_compression() -> Action:
    """
    动作： 压缩，开启 gzip+brotli 压缩，仅在文件大小超过 1000MB 后压缩，要压缩的文件类型为 html、js、css、json
    :return: Action
    """
    action = Action({
        "Action":"compression",
        "Groups": [{
            "Dimension":"compression",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"methods",
                        "Values": ["gzip", "brotli"]
                    },
                    {
                        "Name":"min_file_size",
                        "Values": ["1000"]
                    },
                    {
                        "Name":"min_file_size_unit",
                        "Values": ["MB"]
                    },
                    {
                        "Name":"format",
                        "Values": ["customize"]
                    },
                    {
                        "Name":"content_types",
                        "Values": ["text/html", "application/javascript", "text/css", "application/json"]
                    }
                ]
            }]
        }]
    })
    return action

def action_video_drag() -> Action:
    """
    动作： 视频拖拽，开启视频拖拽
    :return: Action
    """
    action = Action({
        "Action":"video_drag",
        "Groups": [{
            "Dimension":"video_drag",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"switch",
                        "Values": ["true"]
                    },
                ]
            }]
        }]
    })
    return action

def action_origin_range() -> Action:
    """
    动作： Range回源，开启Range回源
    :return: Action
    """
    action = Action({
        "Action":"origin_range",
        "Groups": [{
            "Dimension":"origin_range",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"switch",
                        "Values": ["true"]
                    },
                ]
            }]
        }]
    })
    return action

def action_origin_follow() -> Action:
    """
    动作： 回源重定向跟随，开启回源重定向跟随
    :return: Action
    """
    action = Action({
        "Action":"origin_follow",
        "Groups": [{
            "Dimension":"origin_follow",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"switch",
                        "Values": ["true"]
                    },
                ]
            }]
        }]
    })
    return action

def action_origin_tcp_timeout() -> Action:
    """
    动作： 回源超时时间，将回源连接超时时间设置为 10s
    :return: Action
    """
    action = Action({
        "Action":"origin_tcp_timeout",
        "Groups": [{
            "Dimension":"origin_tcp_timeout",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"connect_timeout",
                        "Values": ["10"]
                    },
                    {
                        "Name":"connect_timeout_unit",
                        "Values": ["sec"]
                    },
                ]
            }]
        }]
    })
    return action

def action_origin_http_timeout() -> Action:
    """
    动作： 回源超时时间，将回源响应超时时间设置为 10s
    :return: Action
    """
    action = Action({
        "Action":"origin_http_timeout",
        "Groups": [{
            "Dimension":"origin_http_timeout",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"read_timeout",
                        "Values": ["10"]
                    },
                    {
                        "Name":"read_timeout_unit",
                        "Values": ["sec"]
                    },
                ]
            }]
        }]
    })
    return action

def action_origin_response_header() -> Action:
    """
    动作： 回源响应头改写，将回源响应头 X-H1 改为 X-H2
    :return: Action
    """
    action = Action({
        "Action":"origin_response_header",
        "Groups": [{
            "Dimension":"origin_response_header",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name": "action",
                        "Values": ["set"]
                    },
                    {
                        "Name":"header_name",
                        "Values": ["X-H1"]
                    },
                    {
                        "Name":"header_value",
                        "Values": ["X-H2"]
                    }
                ]
            }]
        }]
    })
    return action

def action_origin_request_header() -> Action:
    """
    动作： 回源请求头改写，将回源请求头 X-H1 改为 X-H2
    :return: Action
    """
    action = Action({
        "Action":"origin_request_header",
        "Groups": [{
            "Dimension":"origin_request_header",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name": "action",
                        "Values": ["set"]
                    },
                    {
                        "Name":"header_name",
                        "Values": ["X-H1"]
                    },
                    {
                        "Name":"header_value",
                        "Values": ["X-H2"]
                    }
                ]
            }]
        }]
    })
    return action

def action_cache_time() -> Action:
    """
    动作： 缓存时间，将缓存时间设置为 10分钟；缓存策略为遵循源站优先，并补充缓存
    :return: Action
    """
    action = Action({
        "Action":"cache_time",
        "Groups": [{
            "Dimension":"cache_time",
            "GroupParameters": [{
                "Parameters": [
                    {
                        "Name":"ttl",
                        "Values": ["10"]
                    },
                    {
                        "Name":"ttl_unit",
                        "Values": ["min"]
                    },
                    {
                        "Name":"cache_policy",
                        "Values": ["origin_first"]
                    },
                    {
                        "Name":"replenish",
                        "Values": ["true"]
                    }
                ]
            }]
        }]
    })
    return action

def condition_always() -> BaseCondition:
    """
    条件： 总是满足
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "always",
    })
    return condition

def condition_path() -> BaseCondition:
    """
    条件： 路径匹配，等于 /path_source1 或 /path_source2，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "path",
        "Operator": "equal",
        "Value": ["/path_source1", "/path_source2"],
        "IgnoreCase": True
    })
    return condition

def condition_path_and_param() -> BaseCondition:
    """
    条件： 路径和参数匹配，等于 /path1?a=1 或 /path2?b=2，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "path_and_param",
        "Operator": "equal",
        "Value": ["/path1?a=1", "/path2?b=2"],
        "IgnoreCase": True
    })
    return condition

def condition_url() -> BaseCondition:
    """
    条件： URL匹配，等于 http://www.test.com/path1?a=1，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "url",
        "Operator": "equal",
        "Value": ["http://www.test.com/path1?a=1"],
        "IgnoreCase": True
    })
    return condition

def condition_query_string() -> BaseCondition:
    """
    条件： 查询字符串匹配，参数a 等于 1 或 2，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "query_string",
        "Operator": "equal",
        "Value": ["1", "2"],
        "IgnoreCase": True,
        "Name": "a"
    })
    return condition

def condition_http_referer() -> BaseCondition:
    """
    条件： HTTP Referer 匹配，等于 www.test.com，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "http_referer",
        "Operator": "equal",
        "Value": ["www.test.com"],
        "IgnoreCase": True
    })
    return condition

def condition_client_ip() -> BaseCondition:
    """
    条件： 客户端IP匹配，等于 1.1.1.1，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "client_ip",
        "Operator": "match",
        "Value": ["1.1.1.1"]
    })
    return condition

def condition_http_origin() -> BaseCondition:
    """
    条件： HTTP Origin 匹配，等于 www.test.com，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "http_origin",
        "Operator": "equal",
        "Value": ["www.test.com"],
        "IgnoreCase": True
    })
    return condition

def condition_http_user_agent() -> BaseCondition:
    """
    条件： HTTP User-Agent 匹配，等于 Mozilla，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "http_ua",
        "Operator": "equal",
        "Value": ["Mozilla"],
        "IgnoreCase": True
    })
    return condition

def condition_request_header() -> BaseCondition:
    """
    条件： 请求头匹配，请求头 X-H1 等于 1，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "request_header",
        "Operator": "equal",
        "Value": ["1"],
        "IgnoreCase": True,
        "Name": "X-H1"
    })
    return condition

def condition_client_area() -> BaseCondition:
    """
    条件： 客户端地区匹配，等于 CN
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "client_area",
        "Operator": "match",
        "Value": ["CN"]
    })
    return condition

def condition_http_method() -> BaseCondition:
    """
    条件： HTTP Method 匹配，等于 GET
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "http_method",
        "Operator":"equal",
        "Value": ["get"]
    })
    return condition

def condition_request_time() -> BaseCondition:
    """
    条件： 请求时间匹配，每天09:00-20:00，东八区时间
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "request_time",
        "Operator": "match",
        "Value": ["09:00:00", "21:00:00"],
        "TimeZone": "+0800",
        "Name": "everyday"
    })
    return condition

def condition_protocol() -> BaseCondition:
    """
    条件： 协议匹配，等于 http
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "protocol",
        "Operator":"equal",
        "Value": ["http"]
    })
    return condition

def condition_response_header() -> BaseCondition:
    """
    条件： 源站响应头匹配，响应头 X-H1 等于 1，忽略大小写
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object":"response_header",
        "Operator": "equal",
        "Value": ["1"],
        "IgnoreCase": True,
        "Name": "X-H1"
    })
    return condition

def condition_http_code() -> BaseCondition:
    """
    条件： 源站响应状态码匹配，等于 200
    :return: BaseCondition
    """
    condition = BaseCondition({
        "Object": "http_code",
        "Operator":"match",
        "Value": ["200"]
    })
    return condition